==> chaosmesh-model-6.0.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;

 /**
  * Generated
  */
public interface NetworkChaosSpecFluent<A extends NetworkChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  
  /**
   * This method has been deprecated, please use method buildBandwidth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BandwidthSpec getBandwidth();
  public BandwidthSpec buildBandwidth();
  public A withBandwidth(BandwidthSpec bandwidth);
  public Boolean hasBandwidth();
  public A withNewBandwidth(Integer buffer,Integer limit,Long minburst,Long peakrate,String rate);
  public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidth();
  public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidthLike(BandwidthSpec item);
  public NetworkChaosSpecFluent.BandwidthNested<A> editBandwidth();
  public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidth();
  public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidthLike(BandwidthSpec item);
  
  /**
   * This method has been deprecated, please use method buildCorrupt instead.
   * @return The buildable object.
   */
  @Deprecated
  public CorruptSpec getCorrupt();
  public CorruptSpec buildCorrupt();
  public A withCorrupt(CorruptSpec corrupt);
  public Boolean hasCorrupt();
  public A withNewCorrupt(String correlation,String corrupt);
  public NetworkChaosSpecFluent.CorruptNested<A> withNewCorrupt();
  public NetworkChaosSpecFluent.CorruptNested<A> withNewCorruptLike(CorruptSpec item);
  public NetworkChaosSpecFluent.CorruptNested<A> editCorrupt();
  public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorrupt();
  public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorruptLike(CorruptSpec item);
  
  /**
   * This method has been deprecated, please use method buildDelay instead.
   * @return The buildable object.
   */
  @Deprecated
  public DelaySpec getDelay();
  public DelaySpec buildDelay();
  public A withDelay(DelaySpec delay);
  public Boolean hasDelay();
  public NetworkChaosSpecFluent.DelayNested<A> withNewDelay();
  public NetworkChaosSpecFluent.DelayNested<A> withNewDelayLike(DelaySpec item);
  public NetworkChaosSpecFluent.DelayNested<A> editDelay();
  public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelay();
  public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelayLike(DelaySpec item);
  public String getDirection();
  public A withDirection(String direction);
  public Boolean hasDirection();
  
  /**
   * This method has been deprecated, please use method buildDuplicate instead.
   * @return The buildable object.
   */
  @Deprecated
  public DuplicateSpec getDuplicate();
  public DuplicateSpec buildDuplicate();
  public A withDuplicate(DuplicateSpec duplicate);
  public Boolean hasDuplicate();
  public A withNewDuplicate(String correlation,String duplicate);
  public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicate();
  public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicateLike(DuplicateSpec item);
  public NetworkChaosSpecFluent.DuplicateNested<A> editDuplicate();
  public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicate();
  public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicateLike(DuplicateSpec item);
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public A addToExternalTargets(Integer index,String item);
  public A setToExternalTargets(Integer index,String item);
  public A addToExternalTargets(java.lang.String... items);
  public A addAllToExternalTargets(Collection<String> items);
  public A removeFromExternalTargets(java.lang.String... items);
  public A removeAllFromExternalTargets(Collection<String> items);
  public List<String> getExternalTargets();
  public String getExternalTarget(Integer index);
  public String getFirstExternalTarget();
  public String getLastExternalTarget();
  public String getMatchingExternalTarget(Predicate<String> predicate);
  public Boolean hasMatchingExternalTarget(Predicate<String> predicate);
  public A withExternalTargets(List<String> externalTargets);
  public A withExternalTargets(java.lang.String... externalTargets);
  public Boolean hasExternalTargets();
  
  /**
   * This method has been deprecated, please use method buildLoss instead.
   * @return The buildable object.
   */
  @Deprecated
  public LossSpec getLoss();
  public LossSpec buildLoss();
  public A withLoss(LossSpec loss);
  public Boolean hasLoss();
  public A withNewLoss(String correlation,String loss);
  public NetworkChaosSpecFluent.LossNested<A> withNewLoss();
  public NetworkChaosSpecFluent.LossNested<A> withNewLossLike(LossSpec item);
  public NetworkChaosSpecFluent.LossNested<A> editLoss();
  public NetworkChaosSpecFluent.LossNested<A> editOrNewLoss();
  public NetworkChaosSpecFluent.LossNested<A> editOrNewLossLike(LossSpec item);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildScheduler instead.
   * @return The buildable object.
   */
  @Deprecated
  public SchedulerSpec getScheduler();
  public SchedulerSpec buildScheduler();
  public A withScheduler(SchedulerSpec scheduler);
  public Boolean hasScheduler();
  public A withNewScheduler(String cron);
  public NetworkChaosSpecFluent.SchedulerNested<A> withNewScheduler();
  public NetworkChaosSpecFluent.SchedulerNested<A> withNewSchedulerLike(SchedulerSpec item);
  public NetworkChaosSpecFluent.SchedulerNested<A> editScheduler();
  public NetworkChaosSpecFluent.SchedulerNested<A> editOrNewScheduler();
  public NetworkChaosSpecFluent.SchedulerNested<A> editOrNewSchedulerLike(SchedulerSpec item);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public SelectorSpec getSelector();
  public SelectorSpec buildSelector();
  public A withSelector(SelectorSpec selector);
  public Boolean hasSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> withNewSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> withNewSelectorLike(SelectorSpec item);
  public NetworkChaosSpecFluent.SelectorNested<A> editSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(SelectorSpec item);
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public Target getTarget();
  public Target buildTarget();
  public A withTarget(Target target);
  public Boolean hasTarget();
  public NetworkChaosSpecFluent.TargetNested<A> withNewTarget();
  public NetworkChaosSpecFluent.TargetNested<A> withNewTargetLike(Target item);
  public NetworkChaosSpecFluent.TargetNested<A> editTarget();
  public NetworkChaosSpecFluent.TargetNested<A> editOrNewTarget();
  public NetworkChaosSpecFluent.TargetNested<A> editOrNewTargetLike(Target item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface BandwidthNested<N> extends Nested<N>,BandwidthSpecFluent<NetworkChaosSpecFluent.BandwidthNested<N>>{
    public N and();
    public N endBandwidth();
    
  }
  public interface CorruptNested<N> extends Nested<N>,CorruptSpecFluent<NetworkChaosSpecFluent.CorruptNested<N>>{
    public N and();
    public N endCorrupt();
    
  }
  public interface DelayNested<N> extends Nested<N>,DelaySpecFluent<NetworkChaosSpecFluent.DelayNested<N>>{
    public N and();
    public N endDelay();
    
  }
  public interface DuplicateNested<N> extends Nested<N>,DuplicateSpecFluent<NetworkChaosSpecFluent.DuplicateNested<N>>{
    public N and();
    public N endDuplicate();
    
  }
  public interface LossNested<N> extends Nested<N>,LossSpecFluent<NetworkChaosSpecFluent.LossNested<N>>{
    public N and();
    public N endLoss();
    
  }
  public interface SchedulerNested<N> extends Nested<N>,SchedulerSpecFluent<NetworkChaosSpecFluent.SchedulerNested<N>>{
    public N and();
    public N endScheduler();
    
  }
  public interface SelectorNested<N> extends Nested<N>,SelectorSpecFluent<NetworkChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  public interface TargetNested<N> extends Nested<N>,TargetFluent<NetworkChaosSpecFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}

==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;

 /**
  * Generated
  */
public interface NetworkChaosSpecFluent<A extends NetworkChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  
  /**
   * This method has been deprecated, please use method buildBandwidth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BandwidthSpec getBandwidth();
  public BandwidthSpec buildBandwidth();
  public A withBandwidth(BandwidthSpec bandwidth);
  public Boolean hasBandwidth();
  public A withNewBandwidth(Integer buffer,Integer limit,Long minburst,Long peakrate,String rate);
  public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidth();
  public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidthLike(BandwidthSpec item);
  public NetworkChaosSpecFluent.BandwidthNested<A> editBandwidth();
  public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidth();
  public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidthLike(BandwidthSpec item);
  
  /**
   * This method has been deprecated, please use method buildCorrupt instead.
   * @return The buildable object.
   */
  @Deprecated
  public CorruptSpec getCorrupt();
  public CorruptSpec buildCorrupt();
  public A withCorrupt(CorruptSpec corrupt);
  public Boolean hasCorrupt();
  public A withNewCorrupt(String correlation,String corrupt);
  public NetworkChaosSpecFluent.CorruptNested<A> withNewCorrupt();
  public NetworkChaosSpecFluent.CorruptNested<A> withNewCorruptLike(CorruptSpec item);
  public NetworkChaosSpecFluent.CorruptNested<A> editCorrupt();
  public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorrupt();
  public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorruptLike(CorruptSpec item);
  
  /**
   * This method has been deprecated, please use method buildDelay instead.
   * @return The buildable object.
   */
  @Deprecated
  public DelaySpec getDelay();
  public DelaySpec buildDelay();
  public A withDelay(DelaySpec delay);
  public Boolean hasDelay();
  public NetworkChaosSpecFluent.DelayNested<A> withNewDelay();
  public NetworkChaosSpecFluent.DelayNested<A> withNewDelayLike(DelaySpec item);
  public NetworkChaosSpecFluent.DelayNested<A> editDelay();
  public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelay();
  public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelayLike(DelaySpec item);
  public String getDevice();
  public A withDevice(String device);
  public Boolean hasDevice();
  public String getDirection();
  public A withDirection(String direction);
  public Boolean hasDirection();
  
  /**
   * This method has been deprecated, please use method buildDuplicate instead.
   * @return The buildable object.
   */
  @Deprecated
  public DuplicateSpec getDuplicate();
  public DuplicateSpec buildDuplicate();
  public A withDuplicate(DuplicateSpec duplicate);
  public Boolean hasDuplicate();
  public A withNewDuplicate(String correlation,String duplicate);
  public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicate();
  public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicateLike(DuplicateSpec item);
  public NetworkChaosSpecFluent.DuplicateNested<A> editDuplicate();
  public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicate();
  public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicateLike(DuplicateSpec item);
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public A addToExternalTargets(Integer index,String item);
  public A setToExternalTargets(Integer index,String item);
  public A addToExternalTargets(java.lang.String... items);
  public A addAllToExternalTargets(Collection<String> items);
  public A removeFromExternalTargets(java.lang.String... items);
  public A removeAllFromExternalTargets(Collection<String> items);
  public List<String> getExternalTargets();
  public String getExternalTarget(Integer index);
  public String getFirstExternalTarget();
  public String getLastExternalTarget();
  public String getMatchingExternalTarget(Predicate<String> predicate);
  public Boolean hasMatchingExternalTarget(Predicate<String> predicate);
  public A withExternalTargets(List<String> externalTargets);
  public A withExternalTargets(java.lang.String... externalTargets);
  public Boolean hasExternalTargets();
  
  /**
   * This method has been deprecated, please use method buildLoss instead.
   * @return The buildable object.
   */
  @Deprecated
  public LossSpec getLoss();
  public LossSpec buildLoss();
  public A withLoss(LossSpec loss);
  public Boolean hasLoss();
  public A withNewLoss(String correlation,String loss);
  public NetworkChaosSpecFluent.LossNested<A> withNewLoss();
  public NetworkChaosSpecFluent.LossNested<A> withNewLossLike(LossSpec item);
  public NetworkChaosSpecFluent.LossNested<A> editLoss();
  public NetworkChaosSpecFluent.LossNested<A> editOrNewLoss();
  public NetworkChaosSpecFluent.LossNested<A> editOrNewLossLike(LossSpec item);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> withNewSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public NetworkChaosSpecFluent.SelectorNested<A> editSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelector getTarget();
  public PodSelector buildTarget();
  public A withTarget(PodSelector target);
  public Boolean hasTarget();
  public NetworkChaosSpecFluent.TargetNested<A> withNewTarget();
  public NetworkChaosSpecFluent.TargetNested<A> withNewTargetLike(PodSelector item);
  public NetworkChaosSpecFluent.TargetNested<A> editTarget();
  public NetworkChaosSpecFluent.TargetNested<A> editOrNewTarget();
  public NetworkChaosSpecFluent.TargetNested<A> editOrNewTargetLike(PodSelector item);
  public String getTargetDevice();
  public A withTargetDevice(String targetDevice);
  public Boolean hasTargetDevice();
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface BandwidthNested<N> extends Nested<N>,BandwidthSpecFluent<NetworkChaosSpecFluent.BandwidthNested<N>>{
    public N and();
    public N endBandwidth();
    
  }
  public interface CorruptNested<N> extends Nested<N>,CorruptSpecFluent<NetworkChaosSpecFluent.CorruptNested<N>>{
    public N and();
    public N endCorrupt();
    
  }
  public interface DelayNested<N> extends Nested<N>,DelaySpecFluent<NetworkChaosSpecFluent.DelayNested<N>>{
    public N and();
    public N endDelay();
    
  }
  public interface DuplicateNested<N> extends Nested<N>,DuplicateSpecFluent<NetworkChaosSpecFluent.DuplicateNested<N>>{
    public N and();
    public N endDuplicate();
    
  }
  public interface LossNested<N> extends Nested<N>,LossSpecFluent<NetworkChaosSpecFluent.LossNested<N>>{
    public N and();
    public N endLoss();
    
  }
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<NetworkChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  public interface TargetNested<N> extends Nested<N>,PodSelectorFluent<NetworkChaosSpecFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}
